==> crealand-1.0.13-py3-none-any.whl: crealand/_apis/interactive.py <==
from crealand._core.bridge.interface import _call_api_async, _call_api
from crealand._apis.constants import ResultType, ToastPosition, ToastState, Volume,Tone,OptionName

class Dialogue:
    # 立绘对话 获取选项
    option_value = ''
    # @classmethod
    def get_option_value(self):
        return self.option_value

    # 立绘对话 初始化
    @staticmethod
    def init():
        _call_api('web-ide', "api.prepareDialogBoard", [{}])
        

    # 立绘对话 显示
    @staticmethod
    def set_dialogue(
        obj_name: str,
        content: str,
        url: str,
        volume: str = Volume.MEDIUM,
    ):
        _call_api(
            'web-ide',
            "api.showDialog",
            [
                {
                    "speaker": obj_name,
                    "type": volume,
                    "txt": content,
                    "voiceId": '',
                    "imgId":url,
                }
            ],
        )
    @staticmethod
    def set_dialogue_tone(
        obj_name: str,
        content: str,
        url: str,
        tone: str,
        volume: str = Volume.MEDIUM,
    ):
        _call_api(
            'web-ide',
            "api.showDialog",
            [
                {
                    "speaker": obj_name,
                    "type": volume,
                    "txt": content,
                    "voiceId": tone,
                    "imgId":url,
                }
            ],
        )

    # 立绘对话 设置选项
    @staticmethod
    def set_option(opt_name: str, content: str):
        options = {}
        options[opt_name] = content
        _call_api(
            'web-ide',
            "api.setDialogOptions",
            [{"options": options}],
        )

    # 立绘对话选项 显示
    @classmethod
    def set_option_show(self,is_show: bool = True):
        self.option_value = _call_api('web-ide', "api.toggleDialogOptions", [{"show": is_show}])
    #  立绘对话 显示
    @classmethod
    def show(self,is_show: bool = True):
        if is_show == False:
            self.option_value = ''
            
        _call_api('web-ide', "api.toggleDialogBoard", [{"show": is_show}])


class HelpPanel:
    # 帮助面板 初始化
    @staticmethod
    def init():
        _call_api('web-ide', "api.prepareHelpboard", [{}])

    # 帮助面板 设置标题
    @staticmethod
    def set_tips(title: str, url: str):
        _call_api(
            'web-ide',
            "api.addHelpItem",
            [
                {
                    "title": title,
                    "imgId": url,
                }
            ],
        )

    # 帮助面板 显示
    @staticmethod
    def show(is_show: bool = True):
        _call_api(
            'web-ide',
            "api.toggleHelpboard",
            [
                {
                    "show": is_show,
                }
            ],
        )


class TaskPanel:

    # 任务面板 设置标题
    @staticmethod
    def set_task(title: str, nickname: str):
        _call_api(
            'web-ide',
            "api.createTaskboard",
            [
                {
                    "title": title,
                    "alias": nickname,
                }
            ],
        )

    # 任务面板 设置任务项
    @staticmethod
    def set_task_progress(
        task_name: str, subtasks_content: str, completed_tasks: int, total_tasks: int
    ):
        _call_api(
            'web-ide',
            "api.setTaskboard",
            [
                {
                    "alias": task_name,
                    "taskName": subtasks_content,
                    "process": [max(0, completed_tasks), max(1, total_tasks)],
                }
            ],
        )

    # 任务面板 显示
    @staticmethod
    def set_task_show(task_name: str, is_show: bool = True):
        _call_api(
            'web-ide',
            "api.toggleTaskboard",
            [{"alias": task_name, "show": is_show}],
        )


class Speak:
    # 说
    @staticmethod
    def text( runtime_id: int, content: str, time: int):
        _call_api_async(
            'unity', "unity.actor.speak", [runtime_id, content, time]
        )

    # 说-img
    @staticmethod
    def image(runtime_id: int, url: str, time: int):
        _call_api_async(
           'unity', "unity.actor.speakImage", [runtime_id, url, time]
        )


class Interactive:
    # 提示面板显示
    @staticmethod
    def set_tip_show(option: str = ResultType.START):
        _call_api(
            'web-ide',
            "api.showTipboardResult",
            [
                {
                    "result": option,
                }
            ],
        )

    # 提示面板显示
    @staticmethod
    def toast(
        content: str,
        position: str = ToastPosition.TOP,
        state: str = ToastState.DYNAMIC,
    ):
        _call_api_async(
            'web-ide',
            "api.toast",
            [
                {
                    "position": position,
                    "mode": state,
                    "txt": content,
                }
            ],
            
        )

==> crealand-1.0.17-py3-none-any.whl: crealand/_apis/interactive.py <==
from crealand._core.bridge.interface import call_api_async, call_api
from crealand._apis.constants import ResultType, ToastPosition, ToastState, Volume,Tone,OptionName
from crealand._utils.logger_setup import setup_logger

logger = setup_logger()

class Dialogue:
    # 立绘对话 获取选项
    option_value = ''
    # @classmethod
    def get_option_value(self):
        return self.option_value

    # 立绘对话 初始化
    @staticmethod
    def init():
        call_api('web-ide', "api.prepareDialogBoard", [{}])
        

    # 立绘对话 显示
    @staticmethod
    def set_dialogue(
        obj_name: str,
        content: str,
        url: str,
        volume: str = Volume.MEDIUM,
    ):
        call_api(
            'web-ide',
            "api.showDialog",
            [
                {
                    "speaker": obj_name,
                    "type": volume,
                    "txt": content,
                    "voiceId": '',
                    "imgId":url,
                }
            ],
        )
    @staticmethod
    def set_dialogue_tone(
        obj_name: str,
        content: str,
        url: str,
        tone: str,
        volume: str = Volume.MEDIUM,
    ):
        call_api(
            'web-ide',
            "api.showDialog",
            [
                {
                    "speaker": obj_name,
                    "type": volume,
                    "txt": content,
                    "voiceId": tone,
                    "imgId":url,
                }
            ],
        )

    # 立绘对话 设置选项
    @staticmethod
    def set_option(opt_name: str, content: str):
        options = {}
        options[opt_name] = content
        call_api(
            'web-ide',
            "api.setDialogOptions",
            [{"options": options}],
        )

    # 立绘对话选项 显示
    @classmethod
    def set_option_show(self,is_show: bool = True):
        self.option_value = call_api('web-ide', "api.toggleDialogOptions", [{"show": is_show}])
    #  立绘对话 显示
    @classmethod
    def show(self,is_show: bool = True):
        if is_show == False:
            self.option_value = ''
            
        call_api('web-ide', "api.toggleDialogBoard", [{"show": is_show}])


class HelpPanel:
    # 帮助面板 初始化
    @staticmethod
    def init():
        call_api('web-ide', "api.prepareHelpboard", [{}])

    # 帮助面板 设置标题
    @staticmethod
    def set_tips(title: str, url: str):
        call_api(
            'web-ide',
            "api.addHelpItem",
            [
                {
                    "title": title,
                    "imgId": url,
                }
            ],
        )

    # 帮助面板 显示
    @staticmethod
    def show(is_show: bool = True):
        call_api(
            'web-ide',
            "api.toggleHelpboard",
            [
                {
                    "show": is_show,
                }
            ],
        )


class TaskPanel:

    # 任务面板 设置标题
    @staticmethod
    def set_task(title: str, nickname: str):
        call_api(
            'web-ide',
            "api.createTaskboard",
            [
                {
                    "title": title,
                    "alias": nickname,
                }
            ],
        )

    # 任务面板 设置任务项
    @staticmethod
    def set_task_progress(
        task_name: str, subtasks_content: str, completed_tasks: int, total_tasks: int
    ):
        call_api(
            'web-ide',
            "api.setTaskboard",
            [
                {
                    "alias": task_name,
                    "taskName": subtasks_content,
                    "process": [max(0, completed_tasks), max(1, total_tasks)],
                }
            ],
        )

    # 任务面板 显示
    @staticmethod
    def set_task_show(task_name: str, is_show: bool = True):
        call_api(
            'web-ide',
            "api.toggleTaskboard",
            [{"alias": task_name, "show": is_show}],
        )


class Speak:
    # 说
    @staticmethod
    def text( runtime_id: int, content: str, time: int):
        call_api_async(
            'unity', "unity.actor.speak", [runtime_id, content, time]
        )

    # 说-img
    @staticmethod
    def image(runtime_id: int, url: str, time: int):
        call_api_async(
           'unity', "unity.actor.speakImage", [runtime_id, url, time]
        )


class Interactive:
    # 提示面板显示
    @staticmethod
    def set_tip_show(option: str = ResultType.START):
        call_api(
            'web-ide',
            "api.showTipboardResult",
            [
                {
                    "result": option,
                }
            ],
        )

    # 提示面板显示
    @staticmethod
    def toast(
        content: str,
        position: str = ToastPosition.TOP,
        state: str = ToastState.DYNAMIC,
    ):
        logger.info('Enter the function toast')
        call_api_async(
            'web-ide',
            "api.toast",
            [
                {
                    "position": position,
                    "mode": state,
                    "txt": content,
                }
            ],
            
        )
        logger.info('Finish the function toast')
